use crate::client::{JiraCommand, JiraRequestType};
use serde::de::DeserializeOwned;
use url::Url;

#[derive(Debug)]
pub struct SelfCommand<T>
where
    T: DeserializeOwned + Clone,
{
    href: String,
    _marker: std::marker::PhantomData<T>,
}

impl<T> SelfCommand<T>
where
    T: DeserializeOwned + Clone,
{
    pub fn new(href: &str) -> Self {
        Self {
            href: href.to_owned(),
            _marker: std::marker::PhantomData,
        }
    }
}

impl<T> JiraCommand for SelfCommand<T>
where
    T: DeserializeOwned + Clone,
{
    type TResponse = T;
    type TPayload = ();
    const REQUEST_TYPE: JiraRequestType = JiraRequestType::Read;

    fn endpoint(&self) -> String {
        let url = Url::parse(&self.href).unwrap();
        url.path().to_string()
    }

    fn request_body(&self) -> Option<&Self::TPayload> {
        None
    }

    fn query_params(&self) -> Option<Vec<(String, String)>> {
        None
    }
}
